==> io.extendreality.tilia.visuals.interactablehighlighter.unity-1.0.3.tgz: package/README.md <==
[![Tilia logo][Tilia-Image]](#)

> ### Visuals -> Interactable Highlighter for the Unity Software
> Provides the ability to control a highlight state for an interactable object for the Unity software.

[![Release][Version-Release]][Releases]
[![License][License-Badge]][License]
[![Backlog][Backlog-Badge]][Backlog]

## Introduction

The InteractableHighlighter prefab provides a simple mechanism for highlighting an Interactable object upon touching and appropriately disabling the highlight when the object is grabbed or untouched.

> **Requires** the Unity software version `2018.3.10f1` (or above).

## Getting Started

Please refer to the [installation] guide to install this package.

## Documentation

Please refer to the [How To Guides] for usage of this package.

Further documentation can be found within the [Documentation] directory and at https://academy.vrtk.io

## Contributing

Please refer to the Extend Reality [Contributing guidelines] and the [project coding conventions].

## Code of Conduct

Please refer to the Extend Reality [Code of Conduct].

## License

Code released under the [MIT License][License].

[License-Badge]: https://img.shields.io/github/license/ExtendRealityLtd/Tilia.Visuals.InteractableHighlighter.Unity.svg
[Version-Release]: https://img.shields.io/github/release/ExtendRealityLtd/Tilia.Visuals.InteractableHighlighter.Unity.svg
[project coding conventions]: https://github.com/ExtendRealityLtd/.github/blob/master/CONVENTIONS/UNITY3D.md

[Tilia-Image]: https://user-images.githubusercontent.com/1029673/67681496-5bf10700-f985-11e9-9413-e61801b6eab5.png
[License]: LICENSE.md
[Documentation]: Documentation/
[How To Guides]: Documentation/HowToGuides/
[Installation]: Documentation/HowToGuides/Installation/README.md
[Backlog]: http://tracker.vrtk.io
[Backlog-Badge]: https://img.shields.io/badge/project-backlog-78bdf2.svg
[Releases]: ../../releases
[Contributing guidelines]: https://github.com/ExtendRealityLtd/.github/blob/master/CONTRIBUTING.md
[Code of Conduct]: https://github.com/ExtendRealityLtd/.github/blob/master/CODE_OF_CONDUCT.md

==> io.extendreality.tilia.visuals.interactablehighlighter.unity-2.0.4.tgz: package/README.md <==
[![Tilia logo][Tilia-Image]](#)

> ### Visuals -> Interactable Highlighter for the Unity Software
> Provides the ability to control a highlight state for an interactable object for the Unity software.

[![Release][Version-Release]][Releases]
[![License][License-Badge]][License]
[![Backlog][Backlog-Badge]][Backlog]

## Introduction

The InteractableHighlighter prefab provides a simple mechanism for highlighting an Interactable object upon touching and appropriately disabling the highlight when the object is grabbed or untouched.

> **Requires** the Unity software version `2018.3.10f1` (or above).

## Getting Started

Please refer to the [installation] guide to install this package.

## Documentation

Please refer to the [How To Guides] for usage of this package.

Further documentation can be found within the [Documentation] directory and at https://academy.vrtk.io

## Contributing

Please refer to the Extend Reality [Contributing guidelines] and the [project coding conventions].

## Code of Conduct

Please refer to the Extend Reality [Code of Conduct].

## License

Code released under the [MIT License][License].

[License-Badge]: https://img.shields.io/github/license/ExtendRealityLtd/Tilia.Visuals.InteractableHighlighter.Unity.svg
[Version-Release]: https://img.shields.io/github/release/ExtendRealityLtd/Tilia.Visuals.InteractableHighlighter.Unity.svg
[project coding conventions]: https://github.com/ExtendRealityLtd/.github/blob/master/CONVENTIONS/UNITY3D.md

[Tilia-Image]: https://raw.githubusercontent.com/ExtendRealityLtd/related-media/main/github/readme/tilia.png
[License]: LICENSE.md
[Documentation]: Documentation/
[How To Guides]: Documentation/HowToGuides/
[Installation]: Documentation/HowToGuides/Installation/README.md
[Backlog]: http://tracker.vrtk.io
[Backlog-Badge]: https://img.shields.io/badge/project-backlog-78bdf2.svg
[Releases]: ../../releases
[Contributing guidelines]: https://github.com/ExtendRealityLtd/.github/blob/master/CONTRIBUTING.md
[Code of Conduct]: https://github.com/ExtendRealityLtd/.github/blob/master/CODE_OF_CONDUCT.md
